@@ -1,32 +1,19 @@
 /*
- *   Copyright 2005 by Aaron Seigo <aseigo@kde.org>
- *   Copyright 2007 by Riccardo Iaconelli <riccardo@kde.org>
- *   Copyright 2008 by Ménard Alexis <darktears31@gmail.com>
- *   Copyright (c) 2009 Chani Armitage <chani@kde.org>
- *   Copyright 2012 by Marco Martin <mart@kde.org>
- *
- *   This program is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU Library General Public License as
- *   published by the Free Software Foundation; either version 2, or
- *   (at your option) any later version.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details
- *
- *   You should have received a copy of the GNU Library General Public
- *   License along with this program; if not, write to the
- *   Free Software Foundation, Inc.,
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
- */
+    SPDX-FileCopyrightText: 2005 Aaron Seigo <aseigo@kde.org>
+    SPDX-FileCopyrightText: 2007 Riccardo Iaconelli <riccardo@kde.org>
+    SPDX-FileCopyrightText: 2008 Ménard Alexis <darktears31@gmail.com>
+    SPDX-FileCopyrightText: 2009 Chani Armitage <chani@kde.org>
+    SPDX-FileCopyrightText: 2012 Marco Martin <mart@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #include "private/applet_p.h"
 
 #include <config-plasma.h>
 
 #include <QFile>
-#include <qstandardpaths.h>
+#include <QStandardPaths>
 #include <QTimer>
 #include <QJsonArray>
 #include <QDir>
@@ -34,9 +21,9 @@
 #include <QFileInfo>
 #include <QMessageBox>
 
-#include <klocalizedstring.h>
-#include <kkeysequencewidget.h>
-#include <kglobalaccel.h>
+#include <KLocalizedString>
+#include <KKeySequenceWidget>
+#include <KGlobalAccel>
 #include <KConfigLoader>
 #include <kpackage/packageloader.h>
 
@@ -187,7 +174,7 @@ void AppletPrivate::init(const QString &_packagePath, const QVariantList &args)
         QAction *a = new QAction(QIcon::fromTheme(QStringLiteral("widget-alternatives")), i18n("Show Alternatives..."), q);
         a->setVisible(false);
         q->actions()->addAction(QStringLiteral("alternatives"), a);
-        QObject::connect(a, &QAction::triggered, [this] {
+        QObject::connect(a, &QAction::triggered, q, [this] {
             if (q->containment()) {
                 emit q->containment()->appletAlternativesRequested(q);
             }
@@ -201,7 +188,7 @@ void AppletPrivate::init(const QString &_packagePath, const QVariantList &args)
                 auto filter = [&provides](const KPluginMetaData &md) -> bool
                 {
                     const QStringList provided = KPluginMetaData::readStringList(md.rawData(), QStringLiteral("X-Plasma-Provides"));
-                    foreach (const QString &p, provides) {
+                    for (const QString &p : provides) {
                         if (provided.contains(p)) {
                             return true;
                         }
@@ -223,7 +210,7 @@ void AppletPrivate::cleanUpAndDelete()
 {
     // reimplemented in the UI specific library
     if (configLoader) {
-        configLoader->setDefaults();
+        configLoader->clearItems();
     }
 
     resetConfigurationObject();
@@ -246,7 +233,8 @@ void AppletPrivate::setDestroyed(bool destroyed)
 
     Plasma::Containment *asContainment = qobject_cast<Plasma::Containment *>(q);
     if (asContainment) {
-        foreach(Applet *a , asContainment->applets())
+        const auto lstApplets = asContainment->applets();
+        for (Applet *a : lstApplets)
         a->d->setDestroyed(destroyed);
     }
 }
@@ -287,7 +275,7 @@ void AppletPrivate::askDestroy()
 
         actions.append(i18n("Undo"));
         deleteNotification->setActions(actions);
-        QObject::connect(deleteNotification.data(), &KNotification::action1Activated,
+        QObject::connect(deleteNotification.data(), &KNotification::action1Activated, q,
                 [=]() {
                     setDestroyed(false);
                     if (!q->isContainment() && q->containment()) {
@@ -411,10 +399,9 @@ void AppletPrivate::updateShortcuts()
     if (q->isContainment()) {
         //a horrible hack to avoid clobbering corona settings
         //we pull them out, then read, then put them back
-        QList<QString> names;
         QList<QAction *> qactions;
-        names << QStringLiteral("add sibling containment") << QStringLiteral("configure shortcuts") << QStringLiteral("lock widgets");
-        foreach (const QString &name, names) {
+        const QList<QString> names = { QStringLiteral("add sibling containment"), QStringLiteral("configure shortcuts"), QStringLiteral("lock widgets")};
+        for (const QString &name : names) {
             QAction *a = actions->action(name);
             actions->takeAction(a); //FIXME this is stupid, KActionCollection needs a takeAction(QString) method
             qactions << a;
